aboutsummaryrefslogtreecommitdiffstats
path: root/eth/protocol.go
diff options
context:
space:
mode:
Diffstat (limited to 'eth/protocol.go')
-rw-r--r--eth/protocol.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/eth/protocol.go b/eth/protocol.go
index 4bc8bee72..376e4663e 100644
--- a/eth/protocol.go
+++ b/eth/protocol.go
@@ -94,8 +94,8 @@ var errorToString = map[int]string{
}
type txPool interface {
- // AddBatch should add the given transactions to the pool.
- AddBatch([]*types.Transaction) error
+ // AddRemotes should add the given transactions to the pool.
+ AddRemotes([]*types.Transaction) error
// Pending should return pending transactions.
// The slice should be modifiable by the caller.